@@ -9,6 +9,7 @@ import socket
 import struct
 import time
 import threading
+import multiprocessing
 
 from dlt.core import (
     cDLTFilter,
@@ -94,7 +95,7 @@ class DLTFilter(cDLTFilter):
             raise RuntimeError("Could not cleanup DLTFilter")
 
     def __repr__(self):
-        """return the 'official' string representation of an object"""
+        """Return the 'official' string representation of an object"""
         apids = [ctypes.string_at(entry[:DLT_ID_SIZE]) for entry in self.apid]
         ctids = [ctypes.string_at(entry[:DLT_ID_SIZE]) for entry in self.ctid]
 
@@ -150,7 +151,6 @@ class Payload(object):
                     offset += length
 
             elif type_info & DLT_TYPE_INFO_UINT:
-
                 if type_info & DLT_TYPE_INFO_VARI:
                     pass
 
@@ -171,7 +171,6 @@ class Payload(object):
                     raise TypeError("reading 128BIT values not supported")
 
             elif type_info & DLT_TYPE_INFO_SINT:
-
                 if type_info & DLT_TYPE_INFO_VARI:
                     pass
 
@@ -192,7 +191,6 @@ class Payload(object):
                     raise TypeError("reading 128BIT values not supported")
 
             elif type_info & DLT_TYPE_INFO_RAWD:
-
                 if type_info & DLT_TYPE_INFO_VARI:
                     pass
 
@@ -289,7 +287,6 @@ class DLTMessage(cDLTMessage, MessageMode):
     @staticmethod
     def from_bytes(data):
         """Create a class instance from a byte string in DLT storage format"""
-
         msg = DLTMessage()
         storageheader, remainder = msg.extract_storageheader(data)
 
@@ -616,7 +613,10 @@ class cDLTFile(ctypes.Structure):  # pylint: disable=invalid-name
         self.indexed = False
         self.end = False
         self.live_run = kwords.pop("is_live", False)
+        # Stop event for threading usage in caller
         self.stop_reading = threading.Event()
+        # Stop event for process usage in caller
+        self.stop_reading_proc = multiprocessing.Event()
 
     def __repr__(self):
         # pylint: disable=bad-continuation
@@ -767,7 +767,7 @@ class cDLTFile(ctypes.Structure):  # pylint: disable=invalid-name
     def _open_file(self):
         """Open the configured file for processing"""
         file_opened = False
-        while not self.stop_reading.is_set():
+        while not self._is_stop_reading_set():
             if dltlib.dlt_file_open(ctypes.byref(self), self.filename, self.verbose) >= DLT_RETURN_OK:
                 file_opened = True
                 break
@@ -783,14 +783,18 @@ class cDLTFile(ctypes.Structure):  # pylint: disable=invalid-name
         """Logs current message for progress information"""
         length = os.stat(self.filename).st_size
         logger.debug(
-            "Processed %s messages (%s%% of %sfile), next message is apid %s, ctid %s",
+            "Processed %s messages (%s%% of %sfile) from %s, next message is apid %s, ctid %s",
             self.position,
             int(100 * self.file_position / length),
             "live " if self.live_run else "",
+            self.filename,
             self.msg.apid,
             self.msg.ctid,
         )
 
+    def _is_stop_reading_set(self):
+        return self.stop_reading.is_set() or self.stop_reading_proc.is_set()
+
     def __iter__(self):  # pylint: disable=too-many-branches
         """Iterate over messages in the file"""
         logger.debug("Starting File Read")
@@ -804,7 +808,7 @@ class cDLTFile(ctypes.Structure):  # pylint: disable=invalid-name
         self._open_file()
 
         found_data = False
-        while not self.stop_reading.is_set() or corruption_check_try:  # pylint: disable=too-many-nested-blocks
+        while not self._is_stop_reading_set() or corruption_check_try:  # pylint: disable=too-many-nested-blocks
             os_stat = os.stat(self.filename)
             mtime = os_stat.st_mtime
 
@@ -812,7 +816,9 @@ class cDLTFile(ctypes.Structure):  # pylint: disable=invalid-name
                 cached_mtime = mtime
                 corruption_check_try = False
 
-                while dltlib.dlt_file_read(ctypes.byref(self), self.verbose) >= DLT_RETURN_OK:
+                while not self._is_stop_reading_set() and (
+                    dltlib.dlt_file_read(ctypes.byref(self), self.verbose) >= DLT_RETURN_OK
+                ):
                     found_data = True
                     if (
                         self.filter
@@ -860,7 +866,8 @@ class cDLTFile(ctypes.Structure):  # pylint: disable=invalid-name
 
 class DLTClient(cDltClient):
     """DLTClient class takes care about correct initialization and
-    cleanup"""
+    cleanup
+    """
 
     verbose = 0
 
@@ -1042,10 +1049,35 @@ class DLTClient(cDltClient):
         dltlib.dlt_client_main_loop(ctypes.byref(self), None, self.verbose)
 
 
+def py_dlt_file_main_loop(dlt_reader, limit=None, callback=None):
+    """Main loop to read dlt messages from dlt file."""
+    try:
+        for msg in dlt_reader:
+            # send the message to the callback and check whether we
+            # need to continue
+            if callback and not callback(msg):
+                logger.debug("callback returned 'False'. Stopping main loop")
+                return False
+
+            if limit:
+                limit -= 1
+                if limit == 0:
+                    break
+    except IOError as err:
+        # If the dlt file is empty, main_loop should not break, so it returns True
+        if str(err) == DLT_EMPTY_FILE_ERROR:
+            logger.debug("Dlt file is empty now. Wait until content is written")
+            return True
+        raise err
+
+    return True
+
+
 # pylint: disable=too-many-arguments,too-many-return-statements,too-many-branches
 def py_dlt_client_main_loop(client, limit=None, verbose=0, dumpfile=None, callback=None):
     """Reimplementation of dlt_client.c:dlt_client_main_loop() in order to handle callback
-    function return value"""
+    function return value
+    """
     bad_messages = 0
     while True:
         if bad_messages > 100:
